@@ -43,6 +43,7 @@ static gboolean edit_mode = FALSE;
 static const char** args = NULL;
 static gboolean delete_original = FALSE;
 static gboolean rebuild_mime_info_cache = FALSE;
+static gboolean print_version = FALSE;
 static char *vendor_name = NULL;
 static char *target_dir = NULL;
 static GSList *edit_actions = NULL;
@@ -318,6 +319,15 @@ static const GOptionEntry main_options[] = {
     N_("Rebuild the MIME types application database after processing desktop files"),
     NULL
   },
+  {
+    "version",
+    '\0',
+    '\0',
+    G_OPTION_ARG_NONE,
+    &print_version,
+    N_("Show the program version"),
+    NULL
+  },
   {
     "edit-mode",
     '\0',
@@ -837,6 +847,13 @@ main (int argc, char **argv)
   mode_t dir_permissions;
   char *basename;
 
+#ifdef HAVE_PLEDGE
+  if (pledge ("stdio rpath wpath cpath fattr", NULL) == -1) {
+    g_printerr ("pledge\n");
+    return 1;
+  }
+#endif
+
   setlocale (LC_ALL, "");
 
   basename = g_path_get_basename (argv[0]);
@@ -854,6 +871,16 @@ main (int argc, char **argv)
       g_option_group_add_entries (group, install_options);
       g_option_context_add_group (context, group);
     }
+#ifdef HAVE_PLEDGE
+  else
+    {
+      /* In edit mode we can drop the fattr pledge. */
+      if (pledge ("stdio rpath wpath cpath", NULL) == -1) {
+        g_printerr ("pledge in edit_mode\n");
+        return 1;
+      }
+    }
+#endif
 
   group = g_option_group_new ("edit", _("Edition options for desktop file"), _("Show desktop file edition options"), NULL, NULL);
   g_option_group_add_entries (group, edit_options);
@@ -870,6 +897,11 @@ main (int argc, char **argv)
     return 1;
   }
 
+  if (print_version) {
+    g_print("desktop-file-install %s\n", VERSION);
+    return 0;
+  }
+
   if (!edit_mode)
     {
       if (vendor_name == NULL && g_getenv ("DESKTOP_FILE_VENDOR"))
